@@ -1,4 +1,3 @@
-# coding: utf-8
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -18,7 +17,7 @@ class LocalBackend(base.BaseBackend):
     NAME = "local"
 
     def __init__(self, *args, **kwargs):
-        super(LocalBackend, self).__init__("local", **kwargs)
+        super().__init__("local", **kwargs)
 
     def get_pytest_id(self):
         return "local"
