@@ -1,4 +1,3 @@
-# coding: utf-8
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -12,7 +11,7 @@
 # limitations under the License.
 
 
-class Module(object):
+class Module:
     _host = None
 
     @classmethod
@@ -36,5 +35,5 @@ class InstanceModule(Module):
 
     @classmethod
     def get_module(cls, _host):
-        klass = super(InstanceModule, cls).get_module(_host)
+        klass = super().get_module(_host)
         return klass()
